# Welcome to yippy Documentation

`yippy` is a package designed to read a "Yield Input Package" (YIP) in Python and generate the off-axis PSFs, stellar intensity maps, and sky transmission maps.

## Quick Links

```{toctree}
:maxdepth: 2
examples/Basics.ipynb
examples/RadiallySymmetric.ipynb
examples/QuarterSymmetric.ipynb
examples/StellarIntens.ipynb
examples/SkyTrans.ipynb
```
```{toctree}
:maxdepth: 1
develop/_changelog.md
```
